==> jc-1.4.0.tar.gz: javax/print/attribute/standard/Destination.h <==
// public final class javax.print.attribute.standard.Destination

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class bc4a0dc2546ead9f javax_print_attribute_URISyntax
// @dep_class c94bd9a712a78478 javax_print_attribute_standard_Destination

// header file dependencies
// @dep_header javax_print_attribute_URISyntax

#include "javax/print/attribute/URISyntax.h"

#ifndef _JC_javax_print_attribute_standard_Destination_H_
#define _JC_javax_print_attribute_standard_Destination_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_URI$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_Destination$sub_refs	_jc_javax_print_attribute_standard_Destination$sub_refs;
typedef struct _jc_javax_print_attribute_standard_Destination$sub_nonrefs	_jc_javax_print_attribute_standard_Destination$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_Destination$refs	_jc_javax_print_attribute_standard_Destination$refs;
typedef struct _jc_javax_print_attribute_standard_Destination$nonrefs	_jc_javax_print_attribute_standard_Destination$nonrefs;
typedef struct _jc_javax_print_attribute_standard_Destination$object	_jc_javax_print_attribute_standard_Destination$object;

typedef struct _jc_javax_print_attribute_standard_Destination$fields_struct	_jc_javax_print_attribute_standard_Destination$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_Destination$vmethods	_jc_javax_print_attribute_standard_Destination$vmethods;
typedef const struct _jc_javax_print_attribute_standard_Destination$vtable	_jc_javax_print_attribute_standard_Destination$vtable;
typedef const struct _jc_javax_print_attribute_standard_Destination$vtype	_jc_javax_print_attribute_standard_Destination$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_Destination$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24Destination;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_Destination$fields_struct _jc_javax_print_attribute_standard_Destination$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_Destination$method$_init$7c3d63594f030366(_jc_env *, struct _jc_javax_print_attribute_standard_Destination$object *, struct _jc_java_net_URI$object *);

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_Destination$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_Destination$object *);
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_Destination$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_Destination$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_Destination$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_Destination$method_info$getName$bec186f2ce7e1882;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_Destination$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_javax_print_attribute_standard_Destination$vmethods {
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_Destination$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_Destination$object *);
};

// Vtable
struct _jc_javax_print_attribute_standard_Destination$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_URISyntax$vmethods	javax_print_attribute_URISyntax;
	_jc_javax_print_attribute_standard_Destination$vmethods	javax_print_attribute_standard_Destination;
};

// Vtype
struct _jc_javax_print_attribute_standard_Destination$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_Destination$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_Destination$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_Destination$refs {
    _jc_javax_print_attribute_standard_Destination$sub_refs	javax_print_attribute_standard_Destination;
    _jc_javax_print_attribute_URISyntax$sub_refs	javax_print_attribute_URISyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_Destination$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_Destination$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_URISyntax$sub_nonrefs	javax_print_attribute_URISyntax;
    _jc_javax_print_attribute_standard_Destination$sub_nonrefs	javax_print_attribute_standard_Destination;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_Destination$object {
	_jc_javax_print_attribute_standard_Destination$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_Destination$vtype	*vtype;
	_jc_javax_print_attribute_standard_Destination$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_Destination$vtype _jc_javax_print_attribute_standard_Destination$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_Destination, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_Destination$class_object;

#endif	/* _JC_javax_print_attribute_standard_Destination_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/standard/Destination.h <==
// public final class javax.print.attribute.standard.Destination

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class bc4a0dc2546ead9f javax_print_attribute_URISyntax
// @dep_class c94bd9a712a78478 javax_print_attribute_standard_Destination

// header file dependencies
// @dep_header javax_print_attribute_URISyntax

#include "javax/print/attribute/URISyntax.h"

#ifndef _JC_javax_print_attribute_standard_Destination_H_
#define _JC_javax_print_attribute_standard_Destination_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_URI$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_Destination$sub_refs	_jc_javax_print_attribute_standard_Destination$sub_refs;
typedef struct _jc_javax_print_attribute_standard_Destination$sub_nonrefs	_jc_javax_print_attribute_standard_Destination$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_Destination$refs	_jc_javax_print_attribute_standard_Destination$refs;
typedef struct _jc_javax_print_attribute_standard_Destination$nonrefs	_jc_javax_print_attribute_standard_Destination$nonrefs;
typedef struct _jc_javax_print_attribute_standard_Destination$object	_jc_javax_print_attribute_standard_Destination$object;

typedef struct _jc_javax_print_attribute_standard_Destination$fields_struct	_jc_javax_print_attribute_standard_Destination$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_Destination$vmethods	_jc_javax_print_attribute_standard_Destination$vmethods;
typedef const struct _jc_javax_print_attribute_standard_Destination$vtable	_jc_javax_print_attribute_standard_Destination$vtable;
typedef const struct _jc_javax_print_attribute_standard_Destination$vtype	_jc_javax_print_attribute_standard_Destination$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_Destination$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24Destination;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_Destination$fields_struct _jc_javax_print_attribute_standard_Destination$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_Destination$method$_init$7c3d63594f030366(_jc_env *, struct _jc_javax_print_attribute_standard_Destination$object *, struct _jc_java_net_URI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_Destination$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_Destination$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_Destination$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_Destination$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_Destination$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_Destination$method_info$getName$bec186f2ce7e1882;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_Destination$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_attribute_standard_Destination$vmethods {
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_Destination$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_Destination$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_print_attribute_standard_Destination$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_URISyntax$vmethods	javax_print_attribute_URISyntax;
	_jc_javax_print_attribute_standard_Destination$vmethods	javax_print_attribute_standard_Destination;
};

// Vtype
struct _jc_javax_print_attribute_standard_Destination$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_Destination$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_Destination$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_Destination$refs {
    _jc_javax_print_attribute_standard_Destination$sub_refs	javax_print_attribute_standard_Destination;
    _jc_javax_print_attribute_URISyntax$sub_refs	javax_print_attribute_URISyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_Destination$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_Destination$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_URISyntax$sub_nonrefs	javax_print_attribute_URISyntax;
    _jc_javax_print_attribute_standard_Destination$sub_nonrefs	javax_print_attribute_standard_Destination;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_Destination$object {
	_jc_javax_print_attribute_standard_Destination$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_Destination$vtype	*vtype;
	_jc_javax_print_attribute_standard_Destination$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_Destination$vtype _jc_javax_print_attribute_standard_Destination$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_Destination, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_Destination$class_object;

#endif	/* _JC_javax_print_attribute_standard_Destination_H_ */
